;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "tempel-collection" "20260516.1317"
  "Collection of templates for Tempel."
  '((tempel "0.5")
    (emacs  "29.1"))
  :url "https://github.com/Crandel/tempel-collection"
  :commit "4ea6f92ecb69dc38c666bfa6c4a253ff94699c80"
  :revdesc "4ea6f92ecb69"
  :keywords '("tools")
  :authors '(("Vitalii Drevenchuk" . "cradlemann@gmail.com")
             ("Max Penet" . "mpenetr@s-exp.com")
             ("Daniel Mendler" . "mail@daniel-mendler.de"))
  :maintainers '(("Vitalii Drevenchuk" . "cradlemann@gmail.com")
                 ("Max Penet" . "mpenetr@s-exp.com")
                 ("Daniel Mendler" . "mail@daniel-mendler.de")))
